@@ -14,20 +14,6 @@ def extraction_step(
     mlcli_template:str,
     name="Extract Features",
 ):
-    """
-    This step will use the production algorithm
-    to convert pdf,png,jpg,tiff to png
-
-    Args:
-        compute_target: The compute target to run the step on
-        environment: The environment in which to run the script
-        datastore: The datastore that will be used
-        raw_data_dir: The reference to the directory containing the data
-        name: Action name of the node
-
-    Returns:
-        The step, the step outputs dictionary
-    """
 
     run_config = RunConfiguration()
     run_config.target = compute_target
