@@ -4,7 +4,7 @@ import subprocess
 def run_ml_cli(files_directory: str,
                output_directory: str,
                ml_cli_template: str,
-               process_path: str = "/home/ml-cli/Ml.Cli",
+               process_path: str = "/home/ml-cli/MlCli",
                run_path: str = "/home/ml-cli",
                tasks_path: str = "/home/tasks.json"):
     ml_cli_template = ml_cli_template.replace("${files_directory}$", files_directory)
