@@ -14,19 +14,6 @@ def data_ingestion_step(
     chunk_index:int,
     name="Ingest Data",
 ):
-    """
-    This step will ingest data from the specified dataset and pass it to
-    the next step as a temporary data reference.
-
-    Args:
-        compute_target: The compute target to run the step on
-        environment: The environment in which to run the script
-        datastore: The datastore that will be used
-        name: Action name of the node
-
-    Returns:
-        The step, the step outputs dictionary
-    """
 
     run_config = RunConfiguration()
     run_config.target = compute_target
